@@ -23,79 +23,86 @@
 #' @param cutscore numeric or vector: cut-score used for binarization of ordinal
 #'   data. If missing, vector of maximal scores is imputed. See
 #'   \strong{Details}.
-#' @param bin logical: If TRUE, indices are printed also for binarized data.
-#'   See \strong{Details}.
+#' @param bin logical: If TRUE, indices are printed also for binarized data. See
+#'   \strong{Details}.
 #' @param data deprecated. Use argument \code{Data} instead.
 #' @param y deprecated. Use argument \code{criterion} instead.
 #' @param add.bin deprecated. Use argument \code{bin} instead.
 #'
 #' @details For ordinal items the difficulty and discrimination indices take
-#' into account minimal item score as well as range.
+#'   into account minimal item score as well as range.
 #'
-#' For calculation of discrimination ULI index, it is possible to specify the
-#' number of groups \code{k}, and which two groups \code{l} and \code{u} are to
-#' be compared.
+#'   For calculation of discrimination ULI index, it is possible to specify the
+#'   number of groups \code{k}, and which two groups \code{l} and \code{u} are
+#'   to be compared.
 #'
-#' In ordinal items, difficulty is calculated as difference of average score
-#' divided by range (maximal possible score \code{maxscore} minus minimal
-#' possible score \code{minscore}).
+#'   In ordinal items, difficulty is calculated as difference of average score
+#'   divided by range (maximal possible score \code{maxscore} minus minimal
+#'   possible score \code{minscore}).
 #'
-#' If \code{bin} is set to \code{TRUE}, item analysis of binarized data is
-#' included in the output table. In such a case, \code{cutscore} is used for
-#' binarization. When binarizing the \code{Data}, values greater or equal to
-#' cut-score are set to \code{1}, other values are set to \code{0}.
+#'   If \code{bin} is set to \code{TRUE}, item analysis of binarized data is
+#'   included in the output table. In such a case, \code{cutscore} is used for
+#'   binarization. When binarizing the \code{Data}, values greater or equal to
+#'   cut-score are set to \code{1}, other values are set to \code{0}.
 #'
-#' @return
-#' \code{ItemAnalysis} function computes various traditional item analysis indices. Output
-#' is a \code{data.frame} with following columns:
+#' @return \code{ItemAnalysis} function computes various traditional item
+#'   analysis indices. Output is a \code{data.frame} with following columns:
 #'   \item{\code{Difficulty}}{average score of the item divided by its range. }
-#'   \item{\code{Mean}}{average item score. }
-#'   \item{\code{SD}}{standard deviation of the item score. }
-#'   \item{\code{SD.bin}}{standard deviation of the item score for binarized data. }
+#'   \item{\code{Mean}}{average item score. } \item{\code{SD}}{standard
+#'   deviation of the item score. } \item{\code{SD.bin}}{standard deviation of
+#'   the item score for binarized data. }
 #'   \item{\code{Prop.max.score}}{proportion of maximal scores. }
-#'   \item{\code{Min.score}}{minimal score specified in \code{minscore}; if not provided, observed minimal score. }
-#'   \item{\code{Max.score}}{maximal score specified in \code{maxscore}; if not provided, observed maximal score. }
+#'   \item{\code{Min.score}}{minimal score specified in \code{minscore}; if not
+#'   provided, observed minimal score. } \item{\code{Max.score}}{maximal score
+#'   specified in \code{maxscore}; if not provided, observed maximal score. }
 #'   \item{\code{obs.min}}{observed minimal score. }
 #'   \item{\code{obs.max}}{observed maximal score. }
 #'   \item{\code{Cut.Score}}{cut-score specified in \code{cutscore}. }
-#'   \item{\code{gULI}}{generalized ULI. }
-#'   \item{\code{gULI.bin}}{generalized ULI for binarized data. }
-#'   \item{\code{ULI}}{discrimination with ULI using the usual parameters (3 groups, comparing 1st and 3rd). }
-#'   \item{\code{ULI.bin}}{discrimination with ULI using the usual parameters for binarized data (3 groups, comparing 1st and 3rd). }
-#'   \item{\code{RIT}}{item-total correlation (correlation between item score and overall test score). }
-#'   \item{\code{RIT.bin}}{item-total correlation for binarized data. }
-#'   \item{\code{RIR}}{item-rest correlation (correlation between item score and overall test score without the given item). }
+#'   \item{\code{gULI}}{generalized ULI. } \item{\code{gULI.bin}}{generalized
+#'   ULI for binarized data. } \item{\code{ULI}}{discrimination with ULI using
+#'   the usual parameters (3 groups, comparing 1st and 3rd). }
+#'   \item{\code{ULI.bin}}{discrimination with ULI using the usual parameters
+#'   for binarized data (3 groups, comparing 1st and 3rd). }
+#'   \item{\code{RIT}}{item-total correlation (correlation between item score
+#'   and overall test score). } \item{\code{RIT.bin}}{item-total correlation for
+#'   binarized data. } \item{\code{RIR}}{item-rest correlation (correlation
+#'   between item score and overall test score without the given item). }
 #'   \item{\code{RIR.bin}}{item-rest correlation for binarized data. }
-#'   \item{\code{Corr.criterion}}{correlation between item score and criterion \code{criterion}. }
-#'   \item{\code{Corr.criterion.bin}}{correlation between item score and criterion \code{criterion} for binarized data. }
-#'   \item{\code{Index.val}}{item validity index calculated as \code{cor(item, criterion) * sqrt(((N - 1) / N) * var(item))}, see Allen and Yen (1979, Ch.6.4). }
-#'   \item{\code{Index.val.bin}}{item validity index for binarized data. }
-#'   \item{\code{Index.rel}}{item reliability index calculated as \code{cor(item, test) * sqrt(((N - 1) / N) * var(item))}, see Allen and Yen (1979, Ch.6.4). }
-#'   \item{\code{Index.rel.bin}}{item reliability index for binarized data. }
-#'   \item{\code{Index.rel.drop}}{item reliability index 'drop' (scored without item). }
-#'   \item{\code{Index.rel.drop.bin}}{item reliability index 'drop' (scored without item) for binarized data. }
-#'   \item{\code{Alpha.drop}}{Cronbach's alpha without given item. }
-#'   \item{\code{Alpha.drop.bin}}{Cronbach's alpha without given item, for binarized data. }
-#'   \item{\code{Perc.miss}}{Percentage of missed responses on the particular item. }
-#'   \item{\code{Perc.nr}}{Percentage of respondents that did not reached the item nor the subsequent ones, see \code{\link{recode_nr}} function for further details. }
-#' With \code{bin = TRUE}, indices based on binarized dataset are also provided
-#' and marked with \code{bin} suffix.
+#'   \item{\code{Corr.criterion}}{correlation between item score and criterion
+#'   \code{criterion}. } \item{\code{Corr.criterion.bin}}{correlation between
+#'   item score and criterion \code{criterion} for binarized data. }
+#'   \item{\code{Index.val}}{item validity index calculated as \code{cor(item,
+#'   criterion) * sqrt(((N - 1) / N) * var(item))}, see Allen and Yen (1979,
+#'   Ch.6.4). } \item{\code{Index.val.bin}}{item validity index for binarized
+#'   data. } \item{\code{Index.rel}}{item reliability index calculated as
+#'   \code{cor(item, test) * sqrt(((N - 1) / N) * var(item))}, see Allen and Yen
+#'   (1979, Ch.6.4). } \item{\code{Index.rel.bin}}{item reliability index for
+#'   binarized data. } \item{\code{Index.rel.drop}}{item reliability index
+#'   'drop' (scored without item). } \item{\code{Index.rel.drop.bin}}{item
+#'   reliability index 'drop' (scored without item) for binarized data. }
+#'   \item{\code{Alpha.drop}}{Cronbach's alpha without given item. In case of
+#'   two-item dataset, \code{NA}s are returned.}
+#'   \item{\code{Alpha.drop.bin}}{Cronbach's alpha without given item, for
+#'   binarized data. In case of two-item dataset, \code{NA}s are returned.}
+#'   \item{\code{Perc.miss}}{Percentage of missed responses on the particular
+#'   item. } \item{\code{Perc.nr}}{Percentage of respondents that did not
+#'   reached the item nor the subsequent ones, see \code{\link{recode_nr}}
+#'   function for further details. } With \code{bin = TRUE}, indices based on
+#'   binarized dataset are also provided and marked with \code{bin} suffix.
 #'
-#' @author
-#' Patricia Martinkova \cr
-#' Institute of Computer Science of the Czech Academy of Sciences \cr
-#' \email{martinkova@@cs.cas.cz} \cr
+#' @author Patricia Martinkova \cr Institute of Computer Science of the Czech
+#'   Academy of Sciences \cr \email{martinkova@@cs.cas.cz} \cr
 #'
-#' Jan Netik \cr
-#' Department of Psychology, Faculty of Arts, Charles University \cr
+#'   Jan Netik \cr Institute of Computer Science of the Czech Academy of
+#'   Sciences \cr Charles University
+#'   \cr
 #'
-#' Jana Vorlickova \cr
-#' Institute of Computer Science of the Czech Academy of Sciences \cr
+#'   Jana Vorlickova \cr Institute of Computer Science of the Czech Academy of
+#'   Sciences \cr
 #'
-#' Adela Hladka \cr
-#' Institute of Computer Science of the Czech Academy of Sciences \cr
-#' Faculty of Mathematics and Physics, Charles University \cr
-#' \email{hladka@@cs.cas.cz} \cr
+#'   Adela Hladka \cr Institute of Computer Science of the Czech Academy of
+#'   Sciences \cr
+#'   \email{hladka@@cs.cas.cz} \cr
 #'
 #' @references Martinkova, P., Stepanek, L., Drabinova, A., Houdek, J.,
 #'   Vejrazka, M., & Stuka, C. (2017). Semi-real-time analyses of item
@@ -106,8 +113,8 @@
 #'   Allen, M. J. & Yen, W. M. (1979). Introduction to measurement theory.
 #'   Monterey, CA: Brooks/Cole.
 #'
-#' @seealso
-#' \code{\link{DDplot}}, \code{\link{gDiscrim}}, \code{\link{recode_nr}}
+#' @seealso \code{\link{DDplot}}, \code{\link{gDiscrim}},
+#'   \code{\link{recode_nr}}
 #'
 #' @examples
 #' \dontrun{
@@ -140,17 +147,31 @@
 ItemAnalysis <- function(Data, criterion = "none", k = 3, l = 1, u = 3,
                          maxscore = NULL, minscore = NULL, cutscore = NULL, bin = FALSE,
                          data, y, add.bin) {
+
+  # deprecated args handling
   if (!missing(data)) {
-    stop("Argument 'data' deprecated. Please use argument 'Data' instead. ", call. = FALSE)
-  }
-  if (!missing(y)) {
-    stop("Argument 'y' deprecated. Please use argument 'criterion' instead. ", call. = FALSE)
-  }
-  if (!missing(add.bin)) {
-    stop("Argument 'add.bin' deprecated. Please use argument 'bin' instead. ", call. = FALSE)
+    warning("Argument 'data' is deprecated; please use 'Data' instead.",
+      call. = FALSE
+    )
+    Data <- data
   }
 
-  if (!is.matrix(Data) & !is.data.frame(Data)) {
+  if (!missing(y)) {
+    warning("Argument 'y' is deprecated; please use 'criterion' instead.",
+      call. = FALSE
+    )
+    criterion <- y
+  }
+
+  if (!missing(add.bin)) {
+    warning("Argument 'add.bin' is deprecated; please use 'bin' instead.",
+      call. = FALSE
+    )
+    bin <- add.bin
+  }
+
+
+  if (!inherits(Data, c("matrix", "data.frame"))) {
     stop("'Data' must be data.frame or matrix. ",
       call. = FALSE
     )
@@ -306,22 +327,36 @@ ItemAnalysis <- function(Data, criterion = "none", k = 3, l = 1, u = 3,
   }
 
   # Alpha without item
-  alpha_drop_ord <- sapply(1:n, function(i) {
-    withoutItem <- Data[, -i]
-    var <- var(withoutItem)
-    N <- ncol(withoutItem)
-    TOT <- rowSums(withoutItem, na.rm = TRUE)
-    alpha <- N / (N - 1) * (1 - (sum(diag(var)) / var(TOT)))
-  })
-
-  if (bin) {
-    alpha_drop_bin <- sapply(1:n, function(i) {
-      withoutItem <- dataBin[, -i]
+  alpha_drop_ord <- if (n > 2) {
+    sapply(1:n, function(i) {
+      withoutItem <- Data[, -i]
       var <- var(withoutItem)
       N <- ncol(withoutItem)
-      TOT <- rowSums(withoutItem)
+      TOT <- rowSums(withoutItem, na.rm = TRUE)
       alpha <- N / (N - 1) * (1 - (sum(diag(var)) / var(TOT)))
     })
+  } else {
+    # psych solution - uses cov between the remaining and the dropped item
+    # covar <- cov(Data)
+    # covar[1, 2] / c(covar[2, 2], covar[1, 1])
+
+    # return NAs, as the alpha for one item does not seem to be well defined
+    rep(NA_real_, n)
+  }
+
+  if (bin) {
+    alpha_drop_bin <- if (n > 2) {
+      sapply(1:n, function(i) {
+        withoutItem <- dataBin[, -i]
+        var <- var(withoutItem)
+        N <- ncol(withoutItem)
+        TOT <- rowSums(withoutItem)
+        alpha <- N / (N - 1) * (1 - (sum(diag(var)) / var(TOT)))
+      })
+    } else {
+      # return NAs, as the alpha for one item does not make sense
+      rep(NA_real_, n)
+    }
   } else {
     alpha_drop_bin <- NA
   }
