@@ -12,7 +12,7 @@
 #'   recognized not-reached responses coded (default is \code{99})
 #' @param df deprecated. Use argument \code{Data} instead.
 #'
-#' @return The same class as input object, see \code{Data}.
+#' @return A \code{data.frame} object.
 #'
 #' @author
 #' Jan Netik \cr
@@ -46,10 +46,18 @@
 #' summary(HCImissedNR)
 #' @export
 recode_nr <- function(Data, nr_code = 99, df) {
+
+  # deprecated args handling
   if (!missing(df)) {
-    stop("Argument 'df' deprecated. Please use argument 'Data' instead. ", call. = FALSE)
+    warning("Argument 'df' is deprecated; please use 'Data' instead.",
+            call. = FALSE
+    )
+    Data <- df
   }
 
+  # coerce to data.frame (tibble cannot be subset by a matrix)
+  if (inherits(Data, "tbl_df")) Data <- as.data.frame(Data)
+
   if (any(sapply(Data, is.factor))) {
     for (i in 1:ncol(Data)) {
       if (!is.null(levels(Data[, i]))) {
